@@ -1,26 +1,28 @@
 use crate::{
+    num_bigint,
     tx_execution::{deploy_contract, execute_builtin_function_or_default},
-    tx_mock::{AsyncCallTxData, BlockchainUpdate, TxCache, TxInput, TxPanic, TxResult},
+    tx_mock::{AsyncCallTxData, BlockchainUpdate, Promise, TxCache, TxInput, TxPanic, TxResult},
     DebugApi,
 };
 use elrond_wasm::{
     api::{
-        BlockchainApi, SendApi, StorageReadApi, StorageWriteApi, ESDT_MULTI_TRANSFER_FUNC_NAME,
+        BlockchainApiImpl, ManagedTypeApi, SendApi, SendApiImpl, ESDT_MULTI_TRANSFER_FUNC_NAME,
         ESDT_NFT_TRANSFER_FUNC_NAME, ESDT_TRANSFER_FUNC_NAME, UPGRADE_CONTRACT_FUNC_NAME,
     },
     elrond_codec::top_encode_to_vec_u8,
+    err_msg,
     types::{
-        Address, BigUint, CodeMetadata, EsdtTokenPayment, ManagedAddress, ManagedArgBuffer,
-        ManagedBuffer, ManagedFrom, ManagedInto, ManagedVec, TokenIdentifier,
+        heap::Address, BigUint, CodeMetadata, EsdtTokenPayment, ManagedAddress, ManagedArgBuffer,
+        ManagedBuffer, ManagedType, ManagedVec, TokenIdentifier,
     },
 };
 use num_traits::Zero;
 
 impl DebugApi {
-    fn append_endpoint_name_and_args(
+    fn append_endpoint_name_and_args<M: ManagedTypeApi>(
         args: &mut Vec<Vec<u8>>,
-        endpoint_name: &ManagedBuffer<Self>,
-        arg_buffer: &ManagedArgBuffer<Self>,
+        endpoint_name: &ManagedBuffer<M>,
+        arg_buffer: &ManagedArgBuffer<M>,
     ) {
         if !endpoint_name.is_empty() {
             args.push(endpoint_name.to_boxed_bytes().into_vec());
@@ -44,16 +46,16 @@ impl DebugApi {
         tx_result.result_values
     }
 
-    fn perform_execute_on_dest_context(
+    fn prepare_execute_on_dest_context_input(
         &self,
         to: Address,
         egld_value: num_bigint::BigUint,
         func_name: Vec<u8>,
         args: Vec<Vec<u8>>,
-    ) -> Vec<Vec<u8>> {
+    ) -> TxInput {
         let contract_address = &self.input_ref().to;
         let tx_hash = self.get_tx_hash_legacy();
-        let tx_input = TxInput {
+        TxInput {
             from: contract_address.clone(),
             to,
             egld_value,
@@ -63,8 +65,17 @@ impl DebugApi {
             gas_limit: 1000,
             gas_price: 0,
             tx_hash,
-        };
+        }
+    }
 
+    fn perform_execute_on_dest_context(
+        &self,
+        to: Address,
+        egld_value: num_bigint::BigUint,
+        func_name: Vec<u8>,
+        args: Vec<Vec<u8>>,
+    ) -> Vec<Vec<u8>> {
+        let tx_input = self.prepare_execute_on_dest_context_input(to, egld_value, func_name, args);
         let tx_cache = TxCache::new(self.blockchain_cache_rc());
         let (tx_result, blockchain_updates) =
             execute_builtin_function_or_default(tx_input, tx_cache);
@@ -75,7 +86,30 @@ impl DebugApi {
             // also kill current execution
             std::panic::panic_any(TxPanic {
                 status: tx_result.result_status,
-                message: tx_result.result_message.into_bytes(),
+                message: tx_result.result_message,
+            })
+        }
+    }
+
+    fn perform_transfer_execute(
+        &self,
+        to: Address,
+        egld_value: num_bigint::BigUint,
+        func_name: Vec<u8>,
+        args: Vec<Vec<u8>>,
+    ) -> Vec<Vec<u8>> {
+        let tx_input = self.prepare_execute_on_dest_context_input(to, egld_value, func_name, args);
+        let tx_cache = TxCache::new(self.blockchain_cache_rc());
+        let (tx_result, blockchain_updates) =
+            execute_builtin_function_or_default(tx_input, tx_cache);
+
+        if tx_result.result_status == 0 {
+            self.sync_call_post_processing(tx_result, blockchain_updates)
+        } else {
+            // also kill current execution
+            std::panic::panic_any(TxPanic {
+                status: 10,
+                message: err_msg::ERROR_SIGNALLED_BY_SMARTCONTRACT.to_string(),
             })
         }
     }
@@ -102,7 +136,7 @@ impl DebugApi {
 
         let tx_cache = TxCache::new(self.blockchain_cache_rc());
         tx_cache.increase_acount_nonce(contract_address);
-        let (tx_result, blockchain_updates, new_address) =
+        let (tx_result, new_address, blockchain_updates) =
             deploy_contract(tx_input, contract_code, tx_cache);
 
         if tx_result.result_status == 0 {
@@ -114,7 +148,7 @@ impl DebugApi {
             // also kill current execution
             std::panic::panic_any(TxPanic {
                 status: 10,
-                message: b"error signalled by smartcontract".to_vec(),
+                message: err_msg::ERROR_SIGNALLED_BY_SMARTCONTRACT.to_string(),
             })
         }
     }
@@ -126,16 +160,16 @@ impl DebugApi {
         std::panic::panic_any(tx_result)
     }
 
-    fn perform_upgrade_contract(
+    fn perform_upgrade_contract<M: ManagedTypeApi>(
         &self,
-        sc_address: &ManagedAddress<Self>,
-        amount: &BigUint<Self>,
+        sc_address: &ManagedAddress<M>,
+        amount: &BigUint<M>,
         contract_code: Vec<u8>,
         code_metadata: CodeMetadata,
-        arg_buffer: &ManagedArgBuffer<Self>,
+        arg_buffer: &ManagedArgBuffer<M>,
     ) -> ! {
         let recipient = sc_address.to_address();
-        let call_value = self.big_uint_value(amount);
+        let call_value = self.big_uint_handle_to_value(amount.get_raw_handle());
         let contract_address = self.input_ref().to.clone();
         let tx_hash = self.get_tx_hash_legacy();
 
@@ -164,17 +198,26 @@ impl DebugApi {
 }
 
 impl SendApi for DebugApi {
-    fn direct_egld<D>(&self, to: &ManagedAddress<Self>, amount: &BigUint<Self>, _data: D)
+    type SendApiImpl = DebugApi;
+
+    fn send_api_impl() -> Self::SendApiImpl {
+        DebugApi::new_from_static()
+    }
+}
+
+impl SendApiImpl for DebugApi {
+    fn direct_egld<M, D>(&self, to: &ManagedAddress<M>, amount: &BigUint<M>, _data: D)
     where
-        D: ManagedInto<Self, ManagedBuffer<Self>>,
+        M: ManagedTypeApi,
+        D: Into<ManagedBuffer<M>>,
     {
-        let amount_value = self.big_uint_value(amount);
+        let amount_value = self.big_uint_handle_to_value(amount.get_raw_handle());
         let available_egld_balance =
             self.with_contract_account(|account| account.egld_balance.clone());
         if amount_value > available_egld_balance {
             std::panic::panic_any(TxPanic {
                 status: 10,
-                message: b"failed transfer (insufficient funds)".to_vec(),
+                message: "failed transfer (insufficient funds)".to_string(),
             });
         }
 
@@ -187,18 +230,18 @@ impl SendApi for DebugApi {
             .increase_egld_balance(recipient, &amount_value);
     }
 
-    fn direct_egld_execute(
+    fn direct_egld_execute<M: ManagedTypeApi>(
         &self,
-        to: &ManagedAddress<Self>,
-        amount: &BigUint<Self>,
+        to: &ManagedAddress<M>,
+        amount: &BigUint<M>,
         _gas_limit: u64,
-        endpoint_name: &ManagedBuffer<Self>,
-        arg_buffer: &ManagedArgBuffer<Self>,
+        endpoint_name: &ManagedBuffer<M>,
+        arg_buffer: &ManagedArgBuffer<M>,
     ) -> Result<(), &'static [u8]> {
-        let egld_value = self.big_uint_value(amount);
+        let egld_value = self.big_uint_handle_to_value(amount.get_raw_handle());
         let recipient = to.to_address();
 
-        let _ = self.perform_execute_on_dest_context(
+        let _ = self.perform_transfer_execute(
             recipient,
             egld_value,
             endpoint_name.to_boxed_bytes().into_vec(),
@@ -208,14 +251,14 @@ impl SendApi for DebugApi {
         Ok(())
     }
 
-    fn direct_esdt_execute(
+    fn direct_esdt_execute<M: ManagedTypeApi>(
         &self,
-        to: &ManagedAddress<Self>,
-        token: &TokenIdentifier<Self>,
-        amount: &BigUint<Self>,
+        to: &ManagedAddress<M>,
+        token: &TokenIdentifier<M>,
+        amount: &BigUint<M>,
         _gas_limit: u64,
-        endpoint_name: &ManagedBuffer<Self>,
-        arg_buffer: &ManagedArgBuffer<Self>,
+        endpoint_name: &ManagedBuffer<M>,
+        arg_buffer: &ManagedArgBuffer<M>,
     ) -> Result<(), &'static [u8]> {
         let recipient = to.to_address();
         let token_bytes = top_encode_to_vec_u8(token).unwrap();
@@ -224,7 +267,7 @@ impl SendApi for DebugApi {
         let mut args = vec![token_bytes, amount_bytes];
         Self::append_endpoint_name_and_args(&mut args, endpoint_name, arg_buffer);
 
-        let _ = self.perform_execute_on_dest_context(
+        let _ = self.perform_transfer_execute(
             recipient,
             num_bigint::BigUint::zero(),
             ESDT_TRANSFER_FUNC_NAME.to_vec(),
@@ -234,15 +277,15 @@ impl SendApi for DebugApi {
         Ok(())
     }
 
-    fn direct_esdt_nft_execute(
+    fn direct_esdt_nft_execute<M: ManagedTypeApi>(
         &self,
-        to: &ManagedAddress<Self>,
-        token: &TokenIdentifier<Self>,
+        to: &ManagedAddress<M>,
+        token: &TokenIdentifier<M>,
         nonce: u64,
-        amount: &BigUint<Self>,
+        amount: &BigUint<M>,
         _gas_limit: u64,
-        endpoint_name: &ManagedBuffer<Self>,
-        arg_buffer: &ManagedArgBuffer<Self>,
+        endpoint_name: &ManagedBuffer<M>,
+        arg_buffer: &ManagedArgBuffer<M>,
     ) -> Result<(), &'static [u8]> {
         let contract_address = self.input_ref().to.clone();
         let recipient = to.to_address();
@@ -260,7 +303,7 @@ impl SendApi for DebugApi {
 
         Self::append_endpoint_name_and_args(&mut args, endpoint_name, arg_buffer);
 
-        let _ = self.perform_execute_on_dest_context(
+        let _ = self.perform_transfer_execute(
             contract_address,
             num_bigint::BigUint::zero(),
             ESDT_NFT_TRANSFER_FUNC_NAME.to_vec(),
@@ -270,13 +313,13 @@ impl SendApi for DebugApi {
         Ok(())
     }
 
-    fn direct_multi_esdt_transfer_execute(
+    fn direct_multi_esdt_transfer_execute<M: ManagedTypeApi>(
         &self,
-        to: &ManagedAddress<Self>,
-        payments: &ManagedVec<Self, EsdtTokenPayment<Self>>,
+        to: &ManagedAddress<M>,
+        payments: &ManagedVec<M, EsdtTokenPayment<M>>,
         _gas_limit: u64,
-        endpoint_name: &ManagedBuffer<Self>,
-        arg_buffer: &ManagedArgBuffer<Self>,
+        endpoint_name: &ManagedBuffer<M>,
+        arg_buffer: &ManagedArgBuffer<M>,
     ) -> Result<(), &'static [u8]> {
         let contract_address = self.input_ref().to.clone();
         let recipient = to.to_address();
@@ -304,7 +347,7 @@ impl SendApi for DebugApi {
             );
         }
 
-        let _ = self.perform_execute_on_dest_context(
+        let _ = self.perform_transfer_execute(
             contract_address,
             num_bigint::BigUint::zero(),
             ESDT_MULTI_TRANSFER_FUNC_NAME.to_vec(),
@@ -314,14 +357,14 @@ impl SendApi for DebugApi {
         Ok(())
     }
 
-    fn async_call_raw(
+    fn async_call_raw<M: ManagedTypeApi>(
         &self,
-        to: &ManagedAddress<Self>,
-        amount: &BigUint<Self>,
-        endpoint_name: &ManagedBuffer<Self>,
-        arg_buffer: &ManagedArgBuffer<Self>,
+        to: &ManagedAddress<M>,
+        amount: &BigUint<M>,
+        endpoint_name: &ManagedBuffer<M>,
+        arg_buffer: &ManagedArgBuffer<M>,
     ) -> ! {
-        let amount_value = self.big_uint_value(amount);
+        let amount_value = self.big_uint_handle_to_value(amount.get_raw_handle());
         let contract_address = self.input_ref().to.clone();
         let recipient = to.to_address();
         let tx_hash = self.get_tx_hash_legacy();
@@ -336,34 +379,66 @@ impl SendApi for DebugApi {
         self.perform_async_call(call)
     }
 
-    fn deploy_contract(
+    fn create_async_call_raw<M: ManagedTypeApi>(
+        &self,
+        to: &ManagedAddress<M>,
+        amount: &BigUint<M>,
+        endpoint_name: &ManagedBuffer<M>,
+        success_callback: &'static [u8],
+        error_callback: &'static [u8],
+        _gas: u64,
+        _extra_gas_for_callback: u64,
+        arg_buffer: &ManagedArgBuffer<M>,
+    ) {
+        let amount_value = self.big_uint_handle_to_value(amount.get_raw_handle());
+        let contract_address = self.input_ref().to.clone();
+        let recipient = to.to_address();
+        let tx_hash = self.get_tx_hash_legacy();
+
+        let call = AsyncCallTxData {
+            from: contract_address,
+            to: recipient,
+            call_value: amount_value,
+            endpoint_name: endpoint_name.to_boxed_bytes().into_vec(),
+            arguments: arg_buffer.to_raw_args_vec(),
+            tx_hash,
+        };
+
+        let promise = Promise {
+            endpoint: call,
+            success_callback,
+            error_callback,
+        };
+
+        let mut tx_result = self.result_borrow_mut();
+        tx_result.result_calls.promises.push(promise);
+    }
+
+    fn deploy_contract<M: ManagedTypeApi>(
         &self,
         _gas: u64,
-        amount: &BigUint<Self>,
-        code: &ManagedBuffer<Self>,
+        amount: &BigUint<M>,
+        code: &ManagedBuffer<M>,
         _code_metadata: CodeMetadata,
-        arg_buffer: &ManagedArgBuffer<Self>,
-    ) -> (ManagedAddress<Self>, ManagedVec<Self, ManagedBuffer<Self>>) {
-        let egld_value = self.big_uint_value(amount);
+        arg_buffer: &ManagedArgBuffer<M>,
+    ) -> (ManagedAddress<M>, ManagedVec<M, ManagedBuffer<M>>) {
+        let egld_value = self.big_uint_handle_to_value(amount.get_raw_handle());
         let contract_code = code.to_boxed_bytes().into_vec();
         let (new_address, result) =
             self.perform_deploy(contract_code, egld_value, arg_buffer.to_raw_args_vec());
 
-        (
-            ManagedAddress::managed_from(self.clone(), new_address),
-            ManagedVec::managed_from(self.clone(), result),
-        )
+        (ManagedAddress::from(new_address), ManagedVec::from(result))
     }
 
-    fn deploy_from_source_contract(
+    fn deploy_from_source_contract<M: ManagedTypeApi>(
         &self,
         _gas: u64,
-        amount: &BigUint<Self>,
-        source_contract_address: &ManagedAddress<Self>,
+        amount: &BigUint<M>,
+        source_contract_address: &ManagedAddress<M>,
         _code_metadata: CodeMetadata,
-        arg_buffer: &ManagedArgBuffer<Self>,
-    ) -> (ManagedAddress<Self>, ManagedVec<Self, ManagedBuffer<Self>>) {
-        let egld_value = self.big_uint_value(amount);
+        arg_buffer: &ManagedArgBuffer<M>,
+    ) -> (ManagedAddress<M>, ManagedVec<M, ManagedBuffer<M>>) {
+        let egld_value = self.big_uint_handle_to_value(amount.get_raw_handle());
         let source_contract_code = self.get_contract_code(&source_contract_address.to_address());
         let (new_address, result) = self.perform_deploy(
             source_contract_code,
@@ -371,47 +446,44 @@ impl SendApi for DebugApi {
             arg_buffer.to_raw_args_vec(),
         );
 
-        (
-            ManagedAddress::managed_from(self.clone(), new_address),
-            ManagedVec::managed_from(self.clone(), result),
-        )
+        (ManagedAddress::from(new_address), ManagedVec::from(result))
     }
 
-    fn upgrade_contract(
+    fn upgrade_contract<M: ManagedTypeApi>(
         &self,
-        sc_address: &ManagedAddress<Self>,
+        sc_address: &ManagedAddress<M>,
         _gas: u64,
-        amount: &BigUint<Self>,
-        code: &ManagedBuffer<Self>,
+        amount: &BigUint<M>,
+        code: &ManagedBuffer<M>,
         code_metadata: CodeMetadata,
-        arg_buffer: &ManagedArgBuffer<Self>,
+        arg_buffer: &ManagedArgBuffer<M>,
     ) {
         let contract_code = code.to_boxed_bytes().into_vec();
         self.perform_upgrade_contract(sc_address, amount, contract_code, code_metadata, arg_buffer)
     }
 
-    fn upgrade_from_source_contract(
+    fn upgrade_from_source_contract<M: ManagedTypeApi>(
         &self,
-        sc_address: &ManagedAddress<Self>,
+        sc_address: &ManagedAddress<M>,
         _gas: u64,
-        amount: &BigUint<Self>,
-        source_contract_address: &ManagedAddress<Self>,
+        amount: &BigUint<M>,
+        source_contract_address: &ManagedAddress<M>,
         code_metadata: CodeMetadata,
-        arg_buffer: &ManagedArgBuffer<Self>,
+        arg_buffer: &ManagedArgBuffer<M>,
     ) {
         let contract_code = self.get_contract_code(&source_contract_address.to_address());
         self.perform_upgrade_contract(sc_address, amount, contract_code, code_metadata, arg_buffer)
     }
 
-    fn execute_on_dest_context_raw(
+    fn execute_on_dest_context_raw<M: ManagedTypeApi>(
         &self,
         _gas: u64,
-        to: &ManagedAddress<Self>,
-        value: &BigUint<Self>,
-        endpoint_name: &ManagedBuffer<Self>,
-        arg_buffer: &ManagedArgBuffer<Self>,
-    ) -> ManagedVec<Self, ManagedBuffer<Self>> {
-        let egld_value = self.big_uint_value(value);
+        to: &ManagedAddress<M>,
+        value: &BigUint<M>,
+        endpoint_name: &ManagedBuffer<M>,
+        arg_buffer: &ManagedArgBuffer<M>,
+    ) -> ManagedVec<M, ManagedBuffer<M>> {
+        let egld_value = self.big_uint_handle_to_value(value.get_raw_handle());
         let recipient = to.to_address();
 
         let result = self.perform_execute_on_dest_context(
@@ -421,94 +493,47 @@ impl SendApi for DebugApi {
             arg_buffer.to_raw_args_vec(),
         );
 
-        ManagedVec::managed_from(self.clone(), result)
+        ManagedVec::from(result)
     }
 
-    fn execute_on_dest_context_raw_custom_result_range<F>(
+    fn execute_on_dest_context_by_caller_raw<M: ManagedTypeApi>(
         &self,
         _gas: u64,
-        to: &ManagedAddress<Self>,
-        value: &BigUint<Self>,
-        endpoint_name: &ManagedBuffer<Self>,
-        arg_buffer: &ManagedArgBuffer<Self>,
-        range_closure: F,
-    ) -> ManagedVec<Self, ManagedBuffer<Self>>
-    where
-        F: FnOnce(usize, usize) -> (usize, usize),
-    {
-        let egld_value = self.big_uint_value(value);
-        let recipient = to.to_address();
-
-        let num_return_data_before = self.result_borrow_mut().result_values.len();
-
-        let result = self.perform_execute_on_dest_context(
-            recipient,
-            egld_value,
-            endpoint_name.to_boxed_bytes().into_vec(),
-            arg_buffer.to_raw_args_vec(),
-        );
-
-        let num_return_data_after = result.len();
-        let (result_start_index, result_end_index) = range_closure(
-            num_return_data_before as usize,
-            num_return_data_after as usize,
-        );
-
-        ManagedVec::managed_from(
-            self.clone(),
-            result[result_start_index..result_end_index].to_vec(),
-        )
-    }
-
-    fn execute_on_dest_context_by_caller_raw(
-        &self,
-        _gas: u64,
-        _to: &ManagedAddress<Self>,
-        _value: &BigUint<Self>,
-        _endpoint_name: &ManagedBuffer<Self>,
-        _arg_buffer: &ManagedArgBuffer<Self>,
-    ) -> ManagedVec<Self, ManagedBuffer<Self>> {
+        _to: &ManagedAddress<M>,
+        _value: &BigUint<M>,
+        _endpoint_name: &ManagedBuffer<M>,
+        _arg_buffer: &ManagedArgBuffer<M>,
+    ) -> ManagedVec<M, ManagedBuffer<M>> {
         panic!("execute_on_dest_context_by_caller_raw not implemented yet!");
     }
 
-    fn execute_on_same_context_raw(
+    fn execute_on_same_context_raw<M: ManagedTypeApi>(
         &self,
         _gas: u64,
-        _to: &ManagedAddress<Self>,
-        _value: &BigUint<Self>,
-        _endpoint_name: &ManagedBuffer<Self>,
-        _arg_buffer: &ManagedArgBuffer<Self>,
-    ) -> ManagedVec<Self, ManagedBuffer<Self>> {
+        _to: &ManagedAddress<M>,
+        _value: &BigUint<M>,
+        _endpoint_name: &ManagedBuffer<M>,
+        _arg_buffer: &ManagedArgBuffer<M>,
+    ) -> ManagedVec<M, ManagedBuffer<M>> {
         panic!("execute_on_same_context_raw not implemented yet!");
     }
 
-    fn execute_on_dest_context_readonly_raw(
+    fn execute_on_dest_context_readonly_raw<M: ManagedTypeApi>(
         &self,
         _gas: u64,
-        _to: &ManagedAddress<Self>,
-        _endpoint_name: &ManagedBuffer<Self>,
-        _arg_buffer: &ManagedArgBuffer<Self>,
-    ) -> ManagedVec<Self, ManagedBuffer<Self>> {
+        _to: &ManagedAddress<M>,
+        _endpoint_name: &ManagedBuffer<M>,
+        _arg_buffer: &ManagedArgBuffer<M>,
+    ) -> ManagedVec<M, ManagedBuffer<M>> {
         panic!("execute_on_dest_context_readonly_raw not implemented yet!");
     }
 
-    fn storage_store_tx_hash_key(&self, data: &ManagedBuffer<Self>) {
-        let tx_hash = self.get_tx_hash_legacy();
-        self.storage_store_slice_u8(tx_hash.as_bytes(), data.to_boxed_bytes().as_slice());
-    }
-
-    fn storage_load_tx_hash_key(&self) -> ManagedBuffer<Self> {
-        let tx_hash = self.get_tx_hash_legacy();
-        let bytes = self.storage_load_boxed_bytes(tx_hash.as_bytes());
-        ManagedBuffer::new_from_bytes(self.clone(), bytes.as_slice())
-    }
-
-    fn call_local_esdt_built_in_function(
+    fn call_local_esdt_built_in_function<M: ManagedTypeApi>(
         &self,
         _gas: u64,
-        function_name: &ManagedBuffer<Self>,
-        arg_buffer: &ManagedArgBuffer<Self>,
-    ) -> ManagedVec<Self, ManagedBuffer<Self>> {
+        function_name: &ManagedBuffer<M>,
+        arg_buffer: &ManagedArgBuffer<M>,
+    ) -> ManagedVec<M, ManagedBuffer<M>> {
         let contract_address = &self.input_ref().to;
 
         let result = self.perform_execute_on_dest_context(
@@ -518,6 +543,22 @@ impl SendApi for DebugApi {
             arg_buffer.to_raw_args_vec(),
         );
 
-        ManagedVec::managed_from(self.clone(), result)
+        self.clean_return_data();
+
+        ManagedVec::from(result)
+    }
+
+    fn clean_return_data(&self) {
+        let mut tx_result = self.result_borrow_mut();
+        tx_result.result_values.clear();
+    }
+
+    fn delete_from_return_data(&self, index: usize) {
+        let mut tx_result = self.result_borrow_mut();
+        if index > tx_result.result_values.len() {
+            return;
+        }
+
+        let _ = tx_result.result_values.remove(index);
     }
 }
