@@ -1,4 +1,6 @@
+#![feature(generic_associated_types)]
 #![allow(clippy::type_complexity)]
+#![feature(exhaustive_patterns)]
 
 pub mod abi_json;
 pub mod api;
@@ -9,6 +11,7 @@ mod mandos_go_runner;
 mod mandos_rs_runner;
 mod mandos_step;
 pub mod meta;
+pub mod testing_framework;
 pub mod tx_execution;
 pub mod tx_mock;
 pub mod world_mock;
@@ -23,6 +26,12 @@ pub use mandos_rs_runner::mandos_rs;
 pub use tx_mock::DebugApi;
 pub use world_mock::BlockchainMock;
 
+// Re-exporting the whole mandos crate for easier use in tests.
+pub use mandos;
+
+// Re-exporting for convenience. Using the crate as imported in the codec to make sure the save version is used everywhere.
+pub use elrond_wasm::elrond_codec::num_bigint;
+
 #[macro_use]
 extern crate alloc;
 pub use alloc::{boxed::Box, vec::Vec};
