@@ -1,5 +1,5 @@
+use crate::num_bigint::BigUint;
 use elrond_wasm::api::ESDT_LOCAL_BURN_FUNC_NAME;
-use num_bigint::BigUint;
 
 use crate::tx_mock::{BlockchainUpdate, TxCache, TxInput, TxLog, TxResult, TxResultCalls};
 
