@@ -1,4 +1,4 @@
 pub struct TxPanic {
     pub status: u64,
-    pub message: Vec<u8>,
+    pub message: String,
 }
