@@ -1,6 +1,6 @@
+use crate::num_bigint::BigUint;
 use alloc::vec::Vec;
-use elrond_wasm::types::Address;
-use num_bigint::BigUint;
+use elrond_wasm::types::heap::Address;
 use std::{collections::HashMap, fmt, fmt::Write};
 
 use crate::key_hex;
@@ -30,7 +30,7 @@ impl fmt::Display for AccountData {
         for key in &storage_keys {
             let value = self.storage.get(key).unwrap();
             write!(
-                &mut storage_buf,
+                storage_buf,
                 "\n\t\t\t{} -> 0x{}",
                 key_hex(key.as_slice()),
                 hex::encode(value.as_slice())
