@@ -1,6 +1,6 @@
 use std::path::{Path, PathBuf};
 
-use elrond_wasm::contract_base::CallableContract;
+use elrond_wasm::contract_base::{CallableContract, CallableContractBuilder};
 use mandos::{interpret_trait::InterpreterContext, value_interpreter::interpret_string};
 
 use crate::DebugApi;
@@ -24,6 +24,10 @@ pub fn find_workspace() -> PathBuf {
 }
 
 impl BlockchainMock {
+    pub fn interpreter_context(&self) -> InterpreterContext {
+        InterpreterContext::new(self.current_dir.clone())
+    }
+
     /// Tells the tests where the crate lies relative to the workspace.
     /// This ensures that the paths are set correctly, including in debug mode.
     pub fn set_current_dir_from_workspace(&mut self, relative_path: &str) {
@@ -32,16 +36,33 @@ impl BlockchainMock {
         self.current_dir = path;
     }
 
-    pub fn register_contract(
+    pub fn register_contract_obj(
         &mut self,
         expression: &str,
-        new_contract_closure: Box<dyn Fn(DebugApi) -> Box<dyn CallableContract<DebugApi>>>,
+        new_contract_obj: Box<dyn CallableContract>,
     ) {
-        let contract_bytes = interpret_string(
-            expression,
-            &InterpreterContext::new(self.current_dir.clone()),
-        );
+        let contract_bytes = interpret_string(expression, &self.interpreter_context());
+        // panic!("{}", String::from_utf8(contract_bytes).unwrap());
         self.contract_map
-            .register_contract(contract_bytes, new_contract_closure);
+            .register_contract(contract_bytes, new_contract_obj);
+    }
+
+    pub fn register_contract_builder<B: CallableContractBuilder>(
+        &mut self,
+        expression: &str,
+        contract_builder: B,
+    ) {
+        self.register_contract_obj(expression, contract_builder.new_contract_obj::<DebugApi>())
+    }
+
+    pub fn register_external_view_contract_builder<B: CallableContractBuilder>(
+        &mut self,
+        expression: &str,
+        contract_builder: B,
+    ) {
+        self.register_contract_obj(
+            expression,
+            contract_builder.new_contract_obj::<elrond_wasm::api::ExternalViewApi<DebugApi>>(),
+        )
     }
 }
