@@ -1,4 +1,4 @@
-use elrond_wasm::types::Address;
+use elrond_wasm::types::heap::Address;
 
 /// Holds the data for a Elrond standard digital token transaction
 #[derive(Clone, Default, Debug)]
@@ -7,6 +7,6 @@ pub struct EsdtInstanceMetadata {
     pub creator: Option<Address>,
     pub royalties: u64,
     pub hash: Option<Vec<u8>>,
-    pub uri: Option<Vec<u8>>,
+    pub uri: Vec<Vec<u8>>,
     pub attributes: Vec<u8>,
 }
