@@ -1,21 +1,21 @@
 mod account_data;
-mod account_esdt;
 mod block_info;
 mod blockchain_mock;
 mod blockchain_mock_account_util;
 mod blockchain_mock_init;
 mod blockchain_tx_info;
+mod esdt_data;
 mod esdt_instance;
 mod esdt_instance_metadata;
 mod esdt_instances;
 mod esdt_roles;
 
 pub use account_data::*;
-pub use account_esdt::*;
 pub use block_info::*;
 pub use blockchain_mock::*;
 pub use blockchain_mock_account_util::is_smart_contract_address;
 pub use blockchain_tx_info::*;
+pub use esdt_data::*;
 pub use esdt_instance::*;
 pub use esdt_instance_metadata::*;
 pub use esdt_instances::*;
