@@ -1,13 +1,15 @@
-use elrond_wasm::types::{BigUint, ManagedFrom, ManagedVec};
+use std::ops::Deref;
+
+use elrond_wasm::types::{BigUint, ManagedVec};
 use elrond_wasm_debug::DebugApi;
 
 #[test]
 fn test_managed_vec_iter_rev() {
-    let context = DebugApi::dummy();
+    let _ = DebugApi::dummy();
 
-    let mut managed_vec = ManagedVec::new(context.clone());
+    let mut managed_vec = ManagedVec::<DebugApi, BigUint<DebugApi>>::new();
     for i in 20u64..=30u64 {
-        managed_vec.push(BigUint::managed_from(context.clone(), i));
+        managed_vec.push(BigUint::from(i));
     }
     let numbers: Vec<u64> = managed_vec
         .iter()
@@ -27,9 +29,9 @@ fn test_managed_vec_iter_rev() {
 
 #[test]
 fn test_managed_vec_iter_exact_size_trait() {
-    let context = DebugApi::dummy();
+    let _ = DebugApi::dummy();
 
-    let mut managed_vec = ManagedVec::new(context.clone());
+    let mut managed_vec = ManagedVec::<DebugApi, i32>::new();
     for i in 1..=10 {
         managed_vec.push(i);
     }
@@ -46,12 +48,12 @@ fn test_managed_vec_iter_exact_size_trait() {
 
 #[test]
 fn test_into_vec() {
-    let context = DebugApi::dummy();
+    let _ = DebugApi::dummy();
 
-    let mut vec = Vec::new();
-    let mut managed_vec = ManagedVec::new(context.clone());
+    let mut vec = Vec::<BigUint<DebugApi>>::new();
+    let mut managed_vec = ManagedVec::<DebugApi, BigUint<DebugApi>>::new();
     for i in 20u64..=30u64 {
-        let biguint = BigUint::managed_from(context.clone(), i);
+        let biguint = BigUint::from(i);
         managed_vec.push(biguint.clone());
         vec.push(biguint);
     }
@@ -61,12 +63,12 @@ fn test_into_vec() {
 
 #[test]
 fn test_with_self_as_vec() {
-    let context = DebugApi::dummy();
+    let _ = DebugApi::dummy();
 
-    let mut vec = Vec::new();
-    let mut managed_vec = ManagedVec::new(context.clone());
+    let mut vec = Vec::<BigUint<DebugApi>>::new();
+    let mut managed_vec = ManagedVec::<DebugApi, BigUint<DebugApi>>::new();
     for i in 20u64..=30u64 {
-        let biguint = BigUint::managed_from(context.clone(), i);
+        let biguint = BigUint::from(i);
         managed_vec.push(biguint.clone());
         vec.push(biguint);
     }
@@ -86,46 +88,42 @@ fn test_with_self_as_vec() {
 
 #[test]
 fn test_managed_from() {
-    let context = DebugApi::dummy();
+    let _ = DebugApi::dummy();
 
     let mut vec = Vec::new();
     for i in 20u64..=30u64 {
-        let biguint = BigUint::managed_from(context.clone(), i);
+        let biguint = BigUint::from(i);
         vec.push(biguint);
     }
 
-    let managed_vec =
-        ManagedVec::<DebugApi, BigUint<DebugApi>>::managed_from(context.clone(), vec.clone());
+    let managed_vec = ManagedVec::<DebugApi, BigUint<DebugApi>>::from(vec.clone());
 
     assert_eq!(vec, managed_vec.into_vec());
 }
 
 #[test]
 fn test_append_vec() {
-    let context = DebugApi::dummy();
+    let _ = DebugApi::dummy();
 
     let mut vec1 = Vec::new();
     let mut vec2 = Vec::new();
     let mut vec = Vec::new();
 
     for i in 20u64..=30u64 {
-        let biguint = BigUint::managed_from(context.clone(), i);
+        let biguint = BigUint::from(i);
         vec.push(biguint.clone());
         vec1.push(biguint);
     }
 
     for i in 20u64..=30u64 {
-        let biguint = BigUint::managed_from(context.clone(), i);
+        let biguint = BigUint::from(i);
         vec.push(biguint.clone());
         vec2.push(biguint);
     }
 
-    let managed_vec =
-        ManagedVec::<DebugApi, BigUint<DebugApi>>::managed_from(context.clone(), vec.clone());
-    let mut managed_vec1 =
-        ManagedVec::<DebugApi, BigUint<DebugApi>>::managed_from(context.clone(), vec1.clone());
-    let managed_vec2 =
-        ManagedVec::<DebugApi, BigUint<DebugApi>>::managed_from(context.clone(), vec2.clone());
+    let managed_vec = ManagedVec::<DebugApi, BigUint<DebugApi>>::from(vec.clone());
+    let mut managed_vec1 = ManagedVec::<DebugApi, BigUint<DebugApi>>::from(vec1.clone());
+    let managed_vec2 = ManagedVec::<DebugApi, BigUint<DebugApi>>::from(vec2.clone());
 
     managed_vec1.append_vec(managed_vec2);
     assert_eq!(managed_vec, managed_vec1);
@@ -133,21 +131,45 @@ fn test_append_vec() {
 
 #[test]
 fn test_overwrite_with_single_item() {
-    let context = DebugApi::dummy();
+    let _ = DebugApi::dummy();
 
     let mut vec = Vec::new();
     for i in 20u64..=30u64 {
-        let biguint = BigUint::managed_from(context.clone(), i);
+        let biguint = BigUint::from(i);
         vec.push(biguint);
     }
 
-    let mut managed_vec =
-        ManagedVec::<DebugApi, BigUint<DebugApi>>::managed_from(context.clone(), vec.clone());
+    let mut managed_vec = ManagedVec::<DebugApi, BigUint<DebugApi>>::from(vec.clone());
     assert_eq!(vec, managed_vec.clone().into_vec());
 
-    let single_elem = BigUint::managed_from(context.clone(), 100u64);
+    let single_elem = BigUint::from(100u64);
     managed_vec.overwrite_with_single_item(single_elem.clone());
     vec = vec![single_elem];
 
     assert_eq!(vec, managed_vec.into_vec());
 }
+
+#[test]
+fn test_managed_vec_get_mut() {
+    let _ = DebugApi::dummy();
+
+    let mut managed_vec = ManagedVec::<DebugApi, BigUint<DebugApi>>::new();
+    managed_vec.push(BigUint::from(100u32));
+    managed_vec.push(BigUint::from(100u32));
+
+    {
+        let mut first_elem = managed_vec.get_mut(0);
+        *first_elem += 100u32;
+    }
+    assert_eq!(*managed_vec.get(0), 200u32);
+    assert_eq!(*managed_vec.get(1), 100u32);
+
+    {
+        let first_elem = managed_vec.get(0).deref().clone();
+        let mut second_elem = managed_vec.get_mut(1);
+        *second_elem += first_elem;
+    }
+
+    assert_eq!(*managed_vec.get(0), 200u32);
+    assert_eq!(*managed_vec.get(1), 300u32);
+}
